# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`mine`](#mine): Manages mining software and configuration.
* [`mine::config`](#mine--config): Configures the mining software and system services.
* [`mine::install`](#mine--install): installs the mining software.
* [`mine::params`](#mine--params): The parameters class

### Defined types

* [`mine::miner`](#mine--miner): Installs and manages the miner software.

## Classes

### <a name="mine"></a>`mine`

Manages mining software and configuration.

#### Parameters

The following parameters are available in the `mine` class:

* [`wallet`](#-mine--wallet)
* [`worker_name`](#-mine--worker_name)
* [`email`](#-mine--email)
* [`miner_user`](#-mine--miner_user)
* [`coin`](#-mine--coin)
* [`miner`](#-mine--miner)
* [`miner_version`](#-mine--miner_version)
* [`pool`](#-mine--pool)
* [`pool_key`](#-mine--pool_key)
* [`cuda_version`](#-mine--cuda_version)

##### <a name="-mine--wallet"></a>`wallet`

Data type: `String`

The mining wallet public address to use.

##### <a name="-mine--worker_name"></a>`worker_name`

Data type: `String`

The name of the worker to use in the pool address.

##### <a name="-mine--email"></a>`email`

Data type: `String`

The email to use for the pool.

##### <a name="-mine--miner_user"></a>`miner_user`

Data type: `String`

The user to start the mining service and has ownership over mining software.

Default value: `'miner'`

##### <a name="-mine--coin"></a>`coin`

Data type:

```puppet
Enum['ethereum',
  'ravencoin']
```

The coin to install and mine.

Default value: `'ethereum'`

##### <a name="-mine--miner"></a>`miner`

Data type:

```puppet
Enum['nsfminer', 'trex',
  'kawpowminer']
```

The miner to install.

Default value: `'nsfminer'`

##### <a name="-mine--miner_version"></a>`miner_version`

Data type: `String`

The miner software version to use.

Default value: `'1.3.14'`

##### <a name="-mine--pool"></a>`pool`

Data type:

```puppet
Enum['ethermine', 'flypool',
  'nanopool']
```

The pool to use.  See params.pp for values.

Default value: `'ethermine'`

##### <a name="-mine--pool_key"></a>`pool_key`

Data type: `String`

The key in the hash to use for the pool's address.  See params.pp for valid values.

Default value: `'ethermine_usa_west'`

##### <a name="-mine--cuda_version"></a>`cuda_version`

Data type: `Integer`

The major version of cuda to use for miner configuration.

Default value: `11`

### <a name="mine--config"></a>`mine::config`

Configures the mining software and system services.

### <a name="mine--install"></a>`mine::install`

installs the mining software.

### <a name="mine--params"></a>`mine::params`

The parameters class

## Defined types

### <a name="mine--miner"></a>`mine::miner`

Installs and manages the miner software.

#### Parameters

The following parameters are available in the `mine::miner` defined type:

* [`url`](#-mine--miner--url)
* [`version`](#-mine--miner--version)
* [`filename`](#-mine--miner--filename)
* [`binary_name`](#-mine--miner--binary_name)
* [`use_archive`](#-mine--miner--use_archive)
* [`target_path`](#-mine--miner--target_path)

##### <a name="-mine--miner--url"></a>`url`

Data type: `String`

The full path to download the file.

##### <a name="-mine--miner--version"></a>`version`

Data type: `String`

The version of the miner to install.

##### <a name="-mine--miner--filename"></a>`filename`

Data type: `String`

The filename of the software to be downloaded.

##### <a name="-mine--miner--binary_name"></a>`binary_name`

Data type: `String`

The name of the file used to start the miner.

##### <a name="-mine--miner--use_archive"></a>`use_archive`

Data type: `Boolean`

True if should use the defined archive and false otherwise.

Default value: `true`

##### <a name="-mine--miner--target_path"></a>`target_path`

Data type: `String`

The path to the target binary.

Default value: `"${version}/${binary_name}"`

