# @summary Returns the arguments to the specified miner software.
#
# @param coin
#   The coin to install and mine.
#
# @param miner
#   The miner to install.
#
# @param_miner_version
#   The miner software version to use.
#
# @param pool_server
#   The pool's server address.
#
# @param wallet
#   The mining wallet public address to use.
#
# @param worker_name
#   The name of the worker to use in the pool address.
#
# @param email
#   The email to use for the pool.
#
function mine::get_miner_config(String $coin, String $miner, String $pool_server, String $wallet, String $worker_name, String $email,) {
  case $miner {
    'nsfminer' : {
      $pool   = "stratum1+ssl://${mine::wallet}.${mine::worker_name}@${$pool_server}"
      # CUDA '-U'
      # set the block size for CUDA and number of streams
      $output = "'-U --cu-block 256 --cu-streams 4 --report-hashrate -P ${pool}'"
    }
    'trex' : {
      $pool   = "stratum+tcp://${pool_server}"
      $output = "'--algo kawpow -o ${pool} -u ${mine::wallet}.${mine::worker_name} -w RavenRig -p x --api-bind-http 0.0.0.0:4067'"
    }
    'kawpowminer' : {
      $output = "'-P stratum+tcp://${mine::wallet}.${mine::worker_name}@${pool_server} --api-port 4067'"
    }
    default : {
      # defaults to nsfminer
      $pool   = "stratum1+ssl://${mine::wallet}.${mine::worker_name}@${$pool_server}"
      $output = "'-U --cu-block 256 --cu-streams 4 --report-hashrate -P ${pool}'"
    }
  }
}
