# @summary Manages mining software and configuration.
#
# @param wallet
#   The mining wallet public address to use.
#
# @param worker_name
#   The name of the worker to use in the pool address.
#
# @param email
#   The email to use for the pool.
#
# @param miner_user
#   The user to start the mining service and has ownership over mining software.
#
# @param coin
#   The coin to install and mine.
#
# @param miner
#   The miner to install.
#
# @param miner_version
#   The miner software version to use.
#
# @param pool
#   The pool to use.  See params.pp for values.
#
# @param pool_key
#   The key in the hash to use for the pool's address.  See params.pp for valid values.
#
# @param cuda_version
#   The major version of cuda to use for miner configuration.
#
class mine (
  String $wallet,
  String $worker_name,
  String $email,
  String           $miner_user    = 'miner',
  Enum['ethereum',
  'ravencoin']     $coin          = 'ravencoin',
  Enum['nsfminer', 'trex',
  'kawpowminer']   $miner         = 'trex',
  String           $miner_version = '0.26.8',
  Enum['ethermine', 'flypool', 'ravenminer',
  'nanopool']      $pool          = 'ravenminer',
  String           $pool_key      = 'auto',
  Integer          $cuda_version  = 11,
) inherits mine::params {
  $root_dir       = '/opt/mining'
  $miners_dir     = "${root_dir}/miners"
  $runners_dir    = "${root_dir}/runners"
  $mining_command = "${root_dir}/mine.bash"

  # initialize params
  $ethermine_servers  = $mine::params::ethermine_servers
  $flypool_servers    = $mine::params::flypool_servers
  $nanopool_servers   = $mine::params::nanopool_servers
  $ravenminer_servers = $mine::params::ravenminer_servers

  contain mine::install
  contain mine::config

  Class['mine::install'] -> Class['mine::config']
}
