# @summary Installs and manages the miner software.
#
# @param url
#   The full path to download the file.
#
# @param version
#   The version of the miner to install.
#
# @param filename
#   The filename of the software to be downloaded.
#
# @param binary_name
#   The name of the file used to start the miner.
#
# @param use_archive
#   True if should use the defined archive and false otherwise.
#
# @param target_path
#   The path to the target binary.
#
define mine::miner (
  String  $url,
  String  $version,
  String  $filename,
  String  $binary_name,
  Boolean $use_archive = true,
  String  $target_path = "${version}/${binary_name}",
) {
  $miner_root      = "${mine::miners_dir}/${name}"
  $miner_downloads = "${miner_root}/downloads"
  $version_dir     = "${miner_root}/${version}"

  file { [$miner_root,$miner_downloads]:
    ensure  => directory,
    owner   => $mine::miner_user,
    group   => $mine::miner_user,
    require => File[$mine::miners_dir],
  }

  file { $version_dir:
    ensure  => directory,
    owner   => $mine::miner_user,
    group   => $mine::miner_user,
    require => File[$miner_root,$miner_downloads],
  }

  if $use_archive {
    archive { "${$miner_downloads}/${filename}":
      extract      => true,
      extract_path => $version_dir,
      source       => $url,
      creates      => "${version_dir}/${binary_name}",
      cleanup      => true,
      user         => $mine::miner_user,
      group        => $mine::miner_user,
      require      => File[$version_dir],
    }

    file { "${miner_root}/${binary_name}":
      ensure  => link,
      target  => $target_path,
      owner   => $mine::miner_user,
      group   => $mine::miner_user,
      require => Archive["${$miner_downloads}/${filename}"],
    }
  }
}
