# @summary installs the kawpow miner for ravencoin
# @see https://github.com/RavenCommunity/kawpowminer
#
# @param version
#   The version to install.
#
# @param cuda_version
#   The cuda version of the miner to use.
#
class mine::miners::ravencoin::kawpowminer (
  String  $version      = '1.2.4',
  Integer $cuda_version = 11,
) {
  case $facts['os']['release']['full'] {
    '18.04' : {
      $dist = 'ubuntu18'
    }
    '20.04', '21.04' , '21.10' , '22.04' : {
      $dist = 'ubuntu20'
    }
    default : {
      fail("${facts['os']['release']['full']} unsupported")
    }
  }

  $cuda = "cuda${cuda_version}"

  $miner_root      = "${mine::miners_dir}/kawpowminer"
  $miner_downloads = "${miner_root}/downloads"
  $filename        = "kawpowminer-${dist}-${cuda}-${version}.tar.gz"
  $target_dir      = "linux-${dist}-${cuda}-${version}"
  $url             = "https://github.com/RavenCommunity/kawpowminer/releases/download/${version}/${filename}"

  mine::miner { 'kawpowminer':
    url         => $url,
    filename    => $filename,
    version     => $version,
    binary_name => 'kawpowminer',
    target_path => "${version}/${target_dir}/kawpowminer",
  }
}
